autowisp.database.data_model.provenance.mount module — AutoWISP documentation

# autowisp.database.data_model.provenance.mount module

## Class Inheritance Diagram

Define the mount dataset table for the pipeline

class autowisp.database.data_model.provenance.mount.Mount(**kwargs)

  Bases: `DataModelBase`

  The table describing the mounts specified

  __str__()

    Human readable info for the mount.

  id

    A unique identifier for each row.

  mount_type
  mount_type_id

    The identifier of the mount type

  notes

    The notes provided for the mount

  observers
  observing_sessions
  serial_number

    The serial number for each mount

  timestamp

    When record was last changed